@@ -1,22 +1,19 @@
 use Apache ();
 use strict;
+use vars qw($r);
+sub test { $r->print(sprintf "%s", $_[1] ? "ok $_[0]\n" : "not ok $_[0]\n") }
 
-my $tests = 21;
+my $tests = 20;
 my $i;
-my $r = Apache->request;
-$r->content_type("text/plain");
+$r = Apache->request;
+$r->content_type("text/html");
 $r->send_http_header;
 $r->print("1..$tests\n");
 
-sub test { 
-    Apache->request->
-	print(sprintf "%s", $_[1] ? "ok $_[0]\n" : "not ok $_[0]\n");
-}
-
 %ENV = $r->cgi_env;
 
 test ++$i, $ENV{GATEWAY_INTERFACE};
-test ++$i, defined($r->seqno);
+
 test ++$i, $r->protocol;
 #hostname
 test ++$i, $r->status;
